@@ -1,7 +1,7 @@
 package Bundle::CPAN;
 use strict;
 use vars qw($VERSION);
-$VERSION = '1.856'; # use 3 digits to minimize confusion with the
+$VERSION = '1.857'; # use 3 digits to minimize confusion with the
                     # other CPAN.pm
 
 1;
@@ -40,8 +40,16 @@ Digest::SHA
 
 File::HomeDir
 
+Compress::Raw::Zlib -- needed by Compress::Zlib
+
+IO::Compress::Base -- needed by Compress::Zlib
+
+IO::Uncompress::Gunzip -- really IO::Compress::Zlib -- needed by Compress::Zlib
+
 Compress::Zlib
 
+IO::Zlib -- needed by Archive::{Tar,Zip}
+
 Archive::Tar
 
 Archive::Zip
